==> apache-servicecomb-java-chassis-distribution-2.3.5-src.zip: apache-servicecomb-java-chassis-distribution-2.3.5-src/integration-tests/it-consumer/src/main/java/org/apache/servicecomb/it/testcase/TestReactive.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.testcase;

import java.util.concurrent.ExecutionException;

import org.apache.servicecomb.it.Consumers;
import org.apache.servicecomb.it.schema.ReactiveHelloIntf;
import org.junit.Assert;
import org.junit.Test;

public class TestReactive {
  static Consumers<ReactiveHelloIntf> consumers = new Consumers<>("reactiveWithIntf", ReactiveHelloIntf.class);

  @Test
  public void reactiveWithIntf() throws ExecutionException, InterruptedException {
    Assert.assertEquals("hello name", consumers.getIntf().hello("name").get());
  }

  @Test
  public void reactiveWithIntf_rt() {
    Assert.assertEquals("hello name",
        consumers.getSCBRestTemplate().postForObject("/hello", "name", String.class));
  }
}

==> apache-servicecomb-java-chassis-distribution-2.7.4-src.zip: apache-servicecomb-java-chassis-distribution-2.7.4-src/integration-tests/it-consumer/src/main/java/org/apache/servicecomb/it/testcase/TestReactive.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.testcase;

import java.util.concurrent.ExecutionException;

import org.apache.servicecomb.it.Consumers;
import org.apache.servicecomb.it.schema.ReactiveHelloIntf;
import org.junit.Test;
import org.junit.jupiter.api.Assertions;

public class TestReactive {
  static Consumers<ReactiveHelloIntf> consumers = new Consumers<>("reactiveWithIntf", ReactiveHelloIntf.class);

  @Test
  public void reactiveWithIntf() throws ExecutionException, InterruptedException {
    Assertions.assertEquals("hello name", consumers.getIntf().hello("name").get());
  }

  @Test
  public void reactiveWithIntf_rt() {
    Assertions.assertEquals("hello name",
        consumers.getSCBRestTemplate().postForObject("/hello", "name", String.class));
  }
}
